import React from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3';

const width = 850;
const height = 455;
const centerX = width / 2;
const centerY = height / 2;
const strokeWidth = 13;
const eyeOffsetX = 125;
const eyeOffsetY = 50;
const eyebrowYOffset = -70;
const eyeRadius = 35;
const mouthWidth = 10;
const mouthRadius = 75;

//creation of mouth
const mouthArc = arc()
  .innerRadius(-mouthRadius)
  .outerRadius(mouthRadius + mouthWidth)
  .startAngle(Math.PI / 2)
  .endAngle((Math.PI * 3) / 2);

//creation of eye arc
const eyeArc = d3
  .arc()
  .innerRadius(26)
  .outerRadius(40)
  .startAngle(-Math.PI / 3)
  .endAngle(Math.PI / 3);

//creation of ear arc
const earArc = d3
  .arc()
  .innerRadius(30)
  .outerRadius(80)
  .startAngle(-Math.PI / 2)
  .endAngle(Math.PI / 2);

const App = () => (
  <svg width={width} height={height}>
    <g transform={`translate(${centerX},${centerY})`}>
      <ellipse
        cx={0}
        cy={0}
        rx={250}
        ry={150}
        fill="silver"
        stroke="black"
        stroke-width={6}
      />
      <polygon
        points={`${-eyeOffsetX},${-eyeOffsetY - eyeRadius} ${-eyeOffsetX - eyeRadius},${-eyeOffsetY} ${-eyeOffsetX},${-eyeOffsetY + eyeRadius} ${-eyeOffsetX + eyeRadius},${-eyeOffsetY}`}
        fill="brown"
        stroke="black"
        strokeWidth={5}
      />
      <polygon
        points={`${eyeOffsetX},${-eyeOffsetY - eyeRadius} ${eyeOffsetX - eyeRadius},${-eyeOffsetY} ${eyeOffsetX},${-eyeOffsetY + eyeRadius} ${eyeOffsetX + eyeRadius},${-eyeOffsetY}`}
        fill="brown"
        stroke="black"
        strokeWidth={5}
      />
      <polygon
        points="10,-105 100,-135 50,-215"
        fill="black"
        transform="rotate(50) translate(-30, -80)"
      />
      <polygon
        points="10,-125 -80,-125 -50,-205"
        fill="black"
        transform="rotate(-30) translate(-80, -50)"
      />
      <line
        x1={250}
        y1={123}
        x2={-50}
        y2={10}
        stroke="black"
        stroke-width="2"
      />
      <line
        x1={-250}
        y1={123}
        x2={50}
        y2={10}
        stroke="black"
        stroke-width="2"
      />
      <line
        x1={-250}
        y1={70}
        x2={60}
        y2={10}
        stroke="black" //line color
        stroke-width="2" // line width
      />
      <line
        x1={250}
        y1={70}
        x2={-20}
        y2={10}
        stroke="black" //line color
        stroke-width="2" // line width
      />
      <line
        x1={300}
        y1={30}
        x2={60}
        y2={10}
        stroke="black" //line color
        stroke-width="2" // line width
      />
      <line
        x1={-300}
        y1={30}
        x2={-40}
        y2={10}
        stroke="black"
        stroke-width="2"
      />
      <path
        d={eyeArc()}
        transform="rotate(5)    translate(-132,-68)"
        fill="black"
      />
      <path
        d={eyeArc()}
        transform="rotate(-5)    translate(132,-68)"
        fill="black"
      />
      <path
        d={`M -40 60
        A 50 40, 0, 0, 0, 40 60
        A 30 40, 0, 0, 0, -40 60`}
        fill="wheat"
        stroke="black"
        stroke-width="4"
      />
      <path
        d="M 20 100 A 20 20, -30, 0, 0, 130 100"
        fill="none"
        stroke="black"
        strokeWidth="3"
        transform="translate(-70 -20)"
      />
    </g>
  </svg>
);

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
